==> haskell-decimal-0.5.1-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-decimal.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: Decimal
version: 0.5.1
id: Decimal-0.5.1-56zVtZJqKOTFIT1hax0CPK
key: Decimal-0.5.1-56zVtZJqKOTFIT1hax0CPK
license: BSD3
copyright: Paul Johnson, 2013, 2018.
maintainer: paul@cogito.org.uk
stability: beta
homepage: https://github.com/PaulJohnson/Haskell-Decimal
synopsis: Decimal numbers with variable precision
description:
    A decimal number has an integer mantissa and a negative
    exponent.  The exponent can be interpreted as the number
    of decimal places in the value.
category: Math
author: Paul Johnson
exposed: True
indefinite: False
exposed-modules:
    Data.Decimal
abi: 4ac538b7f9ae0a59ac49ceabe47c7ef7
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/Decimal-0.5.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/Decimal-0.5.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/Decimal-0.5.1
hs-libraries: HSDecimal-0.5.1-56zVtZJqKOTFIT1hax0CPK
depends:
    base-4.10.1.0 deepseq-1.4.3.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
haddock-interfaces: /usr/share/doc/haskell-decimal/html/Decimal.haddock
haddock-html: /usr/share/doc/haskell-decimal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-decimal-0.5.1-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-decimal.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: Decimal
version: 0.5.1
id: Decimal-0.5.1-DFIICxwoKFHFNoAderX3MJ
key: Decimal-0.5.1-DFIICxwoKFHFNoAderX3MJ
license: BSD3
copyright: Paul Johnson, 2013, 2018.
maintainer: paul@cogito.org.uk
stability: beta
homepage: https://github.com/PaulJohnson/Haskell-Decimal
synopsis: Decimal numbers with variable precision
description:
    A decimal number has an integer mantissa and a negative
    exponent.  The exponent can be interpreted as the number
    of decimal places in the value.
category: Math
author: Paul Johnson
exposed: True
indefinite: False
exposed-modules:
    Data.Decimal
abi: 7f5c32edd66db3b002f6ccca37220392
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/Decimal-0.5.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/Decimal-0.5.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/Decimal-0.5.1
hs-libraries: HSDecimal-0.5.1-DFIICxwoKFHFNoAderX3MJ
depends:
    base-4.10.1.0 deepseq-1.4.3.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
haddock-interfaces: /usr/share/doc/haskell-decimal/html/Decimal.haddock
haddock-html: /usr/share/doc/haskell-decimal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
